.router-container {
    display: flex;
    flex-direction: column;
    height: calc(100vh - 64px);

    padding-left: 32px;
    padding-right: 32px;
    padding-top: 16px;
    padding-bottom: 16px;

    > {
        flex-grow: 1;
        width: 100%;
    }
}
